# email_listener

email_listener is a Python package for listening in an email folder and processing incoming emails by scraping them, and writing the contents to local text files. These files can then optionally be further processed with custom functions, or left to be used later.

